gemini_cassandra
================

A repository for my master's thesis on speeding up the genome sequencing pipeline by using NoSQL or NewSQL datastores.
A first paper reviewing possible datastores can be found [here](http://www.gossele.be/nosql_newsql_survey.pdf).

As a case study, I am currently working on porting GEMINI, a genome analysis tool from SQLite to Apache Cassandra.
My thesis text (in Dutch), detailing design decisions, can be found here:

[![PDF Status](https://www.sharelatex.com/github/repos/bgossele/zesis/builds/latest/badge.svg)](https://www.sharelatex.com/github/repos/bgossele/zesis/builds/latest/output.pdf)

Both source code and thesis text are still a work in progress.

GEMINI itself is due to:

Paila U, Chapman BA, Kirchner R, Quinlan AR (2013) 
GEMINI: Integrative Exploration of Genetic Variation and Genome Annotations. 
PLoS Comput Biol 9(7): e1003153. doi:10.1371/journal.pcbi.1003153

[Manuscript](http://www.ploscompbiol.org/article/info%3Adoi%2F10.1371%2Fjournal.pcbi.1003153)
